Message

Enum Message 

#[non_exhaustive]
pub enum Message { System { content: Vec<ContentPart>, }, User { content: Vec<ContentPart>, }, Assistant { content: Vec<ContentPart>, tool_calls: Vec<ToolCall>, }, Tool { tool_call_id: String, name: String, content: Vec<ContentPart>, }, }
Chat message role and content.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


System

System instruction message.

Fields

content: Vec<ContentPart>

Message content parts.



User

User message.

Fields

content: Vec<ContentPart>

Message content parts.



Assistant

Assistant message, optionally including tool calls.

Fields

content: Vec<ContentPart>

Message content parts.

tool_calls: Vec<ToolCall>

Tool calls requested by the assistant.



Tool

Tool result message.

Fields

tool_call_id: String

Tool call identifier being answered.

name: String

Tool name that produced the result.

content: Vec<ContentPart>

Tool result content parts.

Implementations

Source

impl Message

pub fn system_text(text: impl Into<String>) -> Self

Creates a system text message.

pub fn user_text(text: impl Into<String>) -> Self

Creates a user text message.

pub fn assistant_text(text: impl Into<String>) -> Self

Creates an assistant text message without tool calls.

pub fn tool_text( tool_call_id: impl Into<String>, name: impl Into<String>, text: impl Into<String>, ) -> Self

Creates a tool result message.

pub fn tool_calls(&self) -> &[ToolCall]

Returns the tool calls from an Assistant message, or empty slice.

pub fn mark_cache_breakpoint(self) -> Self

Marks the last content part of this message as a cache breakpoint.

If the message has no content parts, the marker is a no-op. If the last content part already has a cache control, it is replaced.

This is a convenience for callers that want to place a cache breakpoint at the end of a message (the most common case).